cmoncrawl.processor.pipeline.downloader.AsyncDownloader
=======================================================

.. currentmodule:: cmoncrawl.processor.pipeline.downloader

.. autoclass:: AsyncDownloader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~AsyncDownloader.__init__
      ~AsyncDownloader.aclose
      ~AsyncDownloader.aopen
      ~AsyncDownloader.download
      ~AsyncDownloader.unwrap
   
   

   
   
   